import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format } from 'd3';

const csvUrl ='https://gist.githubusercontent.com/sumitradevipolina/9b5b302957030a5cca12d01939c729a4/raw/832d95bedb5a518af9a7f3363b00b5a6cd4ff93f/gistfile1.txt'
const width = 900;
const height = 500;
const margin = { top: 20, right: 10, bottom: 100, left: 150 };

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.LifeTimeGross = +d['LifeTimeGross'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 5));
    });
  }, []);

  if (!data) {
    return <pre>Preparing...</pre>;
  }
  
  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.Title))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([14000, max(data, d => d.LifeTimeGross)])
    .range([5, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="red" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".50em"
              y={innerHeight + 10}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".12em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Title}
            x={5}
            y={yScale(d.Title)}
            width={xScale(d.LifeTimeGross)}
            height={yScale.bandwidth()/2}
          />
        ))}
        
      </g>
    </svg>
  );
};
ReactDOM.render(<App />, document.getElementById('chart'));
